# RDM - From Theory to Practice: a showcase

## Introduction

This project contains the GNU octave code for a research data management (RDM) showcase.
It was written to show how to compile datasets using the structured GNU octave binary file format and to reuse it for analysis and publication purposes.
All scripts are written in the GNU octave script language. The file formats used are: GNU octave binary *.oct, plain text *.txt and LaTeX script *.tex.
To allow other scientists to use and to modify this work for their own purposes, it is published under an open source license (MIT). See also section *License*.
This showcase was presented for the first time in the course of an invited talk at FELMI-ZFE (Graz University of Technology) on 2023-03-31.

## Author

The author of this work is Jakob Harden. University assistant (junior scientist) and PhD student at the Institute for Technology and Testing of Construction Materials at Graz University of Technology (Graz, Austria). Contact email: jakob.harden@tugraz.at, office@jakobharden.at

## Table of Contents

### Directory structure

- atomic ... atomic structure elements
- latex ... export directory for LaTeX output, LaTeX document script files
- text ... export directory for text output
- dataset ... datasets compiled from rawdata and analysis results (GNU octave binaries)
- rawdata ... rawdata to be compiled into the dataset (CSV and plain text files)

### GNU octave function files

- init.m ... initialize program
- createds.m ... compile dataset from rawdata (input directory is *rawdata*, output directory is *dataset*)
- analseds.m ... analyse dataset (input and output directory is *dataset*)
- plotds.m ... plot contents of dataset data structure (input directory is *dataset*)
- plotads.m ... plot contents of analysis results data structure (input directory is *dataset*)
- export_latex.m ... export content of dataset and analysis results to a LaTeX script file (output directory is *latex*)
- export_text.m ... export content of dataset and analysis results to a plain text file (output directory is *text*)
- README.md ... general documentation

All script files also include the code documentation in order to understand the program logic.

## How to use the scripts

1) Open GNU octave and set the path of the working directory to the location of this program.

2) Run the following commands in GNU octave command line:

2.1) Initialize program: init

2.2) Compile dataset: createds

2.3) Analyse dataset: analyse

2.4) Plot dataset: plotds

2.5) Plot analysis result: plotads

2.6) Export dataset and analysis result to plain text: export_text

2.7) Export dataset and analysis result to LaTeX code: export_latex

3) Open your favourite LaTeX IDE, open and compile the file *main.tex* in the *latex* directory

## License

RDM showcase by Jakob Harden is licensed under the [MIT](https://opensource.org/license/mit/) license.
It is a part of and was written in the course of the PhD thesis of Jakob Harden.

> Copyright (c) 2023 Jakob Harden
>Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
> 
> The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
>
> THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

