## Copyright 2023 Jakob Harden, Graz University of Technology (Graz, Austria)
## This script is a part of and was written in the course of the PhD study of the author.
## License: MIT, see also section "License" in README.md
##
## Analyse data structure
##
function analyseds()

  ## load data set from structure directory
  ds = load('./structure/ds.oct').ds;
  
  ## transform and analyse signal data
  ## amplification parameters
  amp1 = 0.8;
  amp2 = 1.1;
  ## shift parameters
  shft1 = 0.1;
  shft2 = -0.2;
  ## get signal magnitudes
  yy = ds.data.ydata.v;
  ## get signal unit
  yu = ds.data.ydata.u;
  ## amplify magnitudes
  yy = yy .* [amp1, amp2];
  ## shift magnitudes
  yy = yy .+ [shft1, shft2];
  ## get min/max of magnitudes, both signals
  ymin = min(yy);
  ymax = max(yy);
  ymean = mean(yy);
  
  ## create analysis result data structure
  ## copy data set metadata
  ads.meta = ds.meta;
  ## analysis metadata
  ads.ameta.algoname = struct_objattrib('algoname', 'Scale and shift algorithm', 'analysis algorithm name');
  ads.ameta.algover = struct_objdata('algover', 'double_arr', [1, 0], [], 'analysis algorithm version');
  ads.ameta.analyst = ds.meta.creator;
  ads.ameta.title = struct_objattrib('title', 'Signal extrema', 'plot title');
  ads.ameta.xlbl = struct_objattrib('xlbl', 'Signals', 'x axis label');
  ads.ameta.ylbl = struct_objattrib('ylbl', 'min/max(f)', 'y axis label');
  ads.ameta.xunit = struct_objattrib('xunit', 'name', 'x axis label');
  ads.ameta.yunit = struct_objattrib('yunit', yu, 'y axis label');
  ads.ameta.xticklbls = struct_objattrib('xticklbls', {ds.meta.fnaname.v, ds.meta.fnbname.v}, 'x tick labels');
  ## analysis parameters and results
  ads.adata.pampa = struct_objdata('pampa', 'double', amp1, [], 'signal amplification factor, signal 1');
  ads.adata.pampb = struct_objdata('pampb', 'double', amp2, [], 'signal amplification factor, signal 2');
  ads.adata.pshfta = struct_objdata('pshfta', 'double', shft1, yu, 'signal magnitude shift amount, signal 1');
  ads.adata.pshftb = struct_objdata('pshftb', 'double', shft2, yu, 'signal magnitude shift amount, signal 2');
  ads.adata.xdata = ds.data.xdata;
  ads.adata.ydata = struct_objdata('ydata', 'double_mat', yy, yu, 'transformed signal magnitude matrix');
  ads.adata.ymin = struct_objdata('ymin', 'double_arr', ymin, yu, 'minimum of transformed signal magnitude matrix');
  ads.adata.ymax = struct_objdata('ymax', 'double_arr', ymax, yu, 'maximum of transformed signal magnitude matrix');
  ads.adata.ymean = struct_objdata('ymean', 'double_arr', ymean, yu, 'mean of transformed signal magnitude matrix');
  
  
  ## save binary file to structure directory
  save('-binary', './structure/ads.oct', 'ads');

endfunction
