## Copyright 2023 Jakob Harden, Graz University of Technology (Graz, Austria)
## This script is a part of and was written in the course of the PhD study of the author.
## License: MIT, see also section "License" in README.md
##
## Create atomic attribute object (atomic attribute element, AAE)
##
## Usage: [r_ds] = struct_objattrib(p_t, p_v, p_d)
##
## p_t  ... attribute tag, <str>
## p_v  ... attribute value, <str> or {<str>}
## p_d  ... description, <str>
## r_ds ... return: data structure, <AAE/struct>
##   .obj ... object type, "AAE"
##   .ver ... version numbers [main_ver, sub_ver], [<uint>]
##   .t ... attribute tag, <str>
##   .v ... attribute value, optional, <str> or {<str>}
##   .d ... description, optional, <str>
##
## see also: struct_objdata, struct_objref
##
function [r_ds] = struct_objattrib(p_t, p_v, p_d)
  
  ## check arguments
  if (nargin < 1)
    help struct_objattrib;
    error('Less arguments given!');
  endif
  if (nargin < 2)
    p_v = '';
  endif
  if (nargin < 3)
    p_d = '';
    warning('Description of atomic attribute element is empty!');
  endif
  if isempty(p_t)
    help struct_objattrib;
    error('Attribute tag is empty!');
  endif
  if isempty(p_v)
    p_v = '';
  endif
  
  ## create structure
  r_ds.obj = 'AAE';
  r_ds.ver = uint16([1, 0]);
  r_ds.t = p_t;
  r_ds.v = p_v;
  r_ds.d = p_d;
  
endfunction
