## Copyright 2023 Jakob Harden, Graz University of Technology (Graz, Austria)
## This script is a part of and was written in the course of the PhD study of the author.
## License: MIT, see also section "License" in README.md
##
## TeXify atomic reference element
##
## Usage: [r_tc] = struct_objref_totex(p_ds, p_dn)
##
## p_ds ... data structure "objref", <AAE/struct>
## p_dn ... data structure name (used as variable name prefix), <str>
## r_tc ... return: TeX code representation of structure element(s), {<str>}
##
## see also: struct_objref
##
function [r_tc] = struct_objref_totex(p_ds, p_dn)
  
  ## check arguments
  if (nargin < 2)
    help struct_objref_totex;
    error('Less arguments given!');
  endif
  
  ## check type of data structure
  if (not(isfield(p_ds, 'obj')))
    warning('Data structure is not of type REFERENCE! name = %s', p_dn);
    r_tc = '';
    return;
  else
    if (not(p_ds.obj == 'ARE'))
      warning('Data structure is not of type REFERENCE! name = %s', p_dn);
      r_tc = '';
      return;
    endif
  endif
  
  ## render data structure to TeX code
  r_tc = {};
  r_tc = [r_tc; sprintf('\\def\\%sobj{%s}', p_dn, hlp_texify(p_ds.obj))];
  r_tc = [r_tc; sprintf('\\def\\%sver{%d.%d}', p_dn, p_ds.ver(1), p_ds.ver(2))];
  r_tc = [r_tc; sprintf('\\def\\%st{%s}', p_dn, hlp_texify(p_ds.t))];
  r_tc = [r_tc; sprintf('\\def\\%sd{%s}', p_dn, hlp_texify(p_ds.d))];
  for i = 1 : max(size(p_ds.i))
    r_tc = [r_tc; sprintf('\\def\\%si%d{%d}', p_dn, i, p_ds.i(i))];
  endfor
  for i = 1 : max(size(p_ds.r))
    r_tc = [r_tc; sprintf('\\def\\%sr%d{%s}', p_dn, i, hlp_texify(p_ds.r{i}))];
  endfor
  
endfunction

function [r_val] = hlp_texify(p_val)
  
  ## escape underscore
  if not(isempty(p_val))
    r_val = strrep(p_val, '_', '\\_');
  else
    r_val = '';
  endif
  
endfunction
