## Copyright 2023 Jakob Harden, Graz University of Technology (Graz, Austria)
## This script is a part of and was written in the course of the PhD study of the author.
## License: MIT, see also section "License" in README.md
##
## TeXify structure containing atomic elements
##
## Usage: [r_tc] = struct_tostring(p_ds, p_mod)
##
## p_ds ... data structure, <struct>
## p_mo  ... mode, <str>
##             'tag' ... print tag only
##             'target' ... print reference target only
##             'id' ... print referenced element id only, as string
##             'target_id' ... print target and id of referenced element, format <target>(<id>)
##             'description' ... print desription as string 
##             'all' ... print all contents (default)
## r_ss ... return: string representation of structure, {<str>}
##
## see also: struct_objref_tostring, struct_objattrib_tostring, struct_objdata_tostring
##
function [r_ss] = struct_tostring(p_ds, p_mo)
  
  ## get field names
  flds = fieldnames(p_ds);
  
  ## get TeX code for all fields
  r_ss = {};
  for i = 1 : max(size(flds))
    fn = flds{i};
    fo = getfield(p_ds, fn);
    r_ss = [r_ss; hlp_export_field(fo, p_mo)];
  endfor
  
endfunction

function [r_ss] = hlp_export_field(p_fo, p_mo)
  ##
  ## helper function: export structure field
  ##
  
  r_ss = {};
  
  if isfield(p_fo, "obj")
    switch (p_fo.obj)
      case "ADE"
        ## data
        r_ss = struct_objdata_tostring(p_fo, p_mo);
      case "ARE"
        ## reference
        r_ss = struct_objref_tostring(p_fo, p_mo);
      case "AAE"
        ## attribute
        r_ss = struct_objattrib_tostring(p_fo, p_mo);
    endswitch
  endif
  
endfunction
