## Copyright 2023 Jakob Harden, Graz University of Technology (Graz, Austria)
## This script is a part of and was written in the course of the PhD study of the author.
## License: MIT, see also section "License" in README.md
##
## TeXify structure containing atomic elements
##
## Usage: [r_tc] = struct_totex(p_ds, p_dn)
##
## p_ds ... data structure, <struct>
## p_dn ... data structure name (used as variable name prefix), <str>
## r_tc ... return: TeX code representation of structure, {<str>}
##
## see also: struct_objref_totex, struct_objattrib_totex, struct_objdata_totex
##
function [r_tc] = struct_totex(p_ds, p_dn)
  
  ## get field names
  flds = fieldnames(p_ds);
  
  ## get TeX code for all fields
  r_tc = {};
  for i = 1 : max(size(flds))
    fn = flds{i};
    fo = getfield(p_ds, fn);
    r_tc = [r_tc; hlp_export_field(fo, sprintf('%s%s', p_dn, fn))];
  endfor
  
endfunction

function [r_tc] = hlp_export_field(p_fo, p_fn)
  ##
  ## helper function: export structure field
  ##
  
  r_tc = {};
  
  if isfield(p_fo, "obj")
    switch (p_fo.obj)
      case "ADE"
        ## data
        r_tc = struct_objdata_totex(p_fo, p_fn);
      case "ARE"
        ## reference
        r_tc = struct_objref_totex(p_fo, p_fn);
      case "AAE"
        ## attribute
        r_tc = struct_objattrib_totex(p_fo, p_fn);
    endswitch
  endif
  
endfunction
