## Copyright 2023 Jakob Harden, Graz University of Technology (Graz, Austria)
## This script is a part of and was written in the course of the PhD study of the author.
## License: MIT, see also section "License" in README.md
##
## Export data structure to LaTeX file
##
function export_latex()

  ## load data set from structure directory
  ds = load('./structure/ds.oct').ds;
  
  ## load analysis result from structure directory
  ads = load('./structure/ads.oct').ads;
  
  ## combine xdata and ydata into one matrix (simplify plotting in LaTeX)
  ds.data.pltdata = struct_objdata('pltdata', 'double_mat', [ds.data.xdata.v, ds.data.ydata.v], [], 'columns: time, signal1, signal2');
  ads.adata.pltdata = struct_objdata('pltadata', 'double_mat', [ads.adata.xdata.v, ads.adata.ydata.v], [], 'columns: time, signal1, signal2');
  
  ## compile TeX code for data set and analysis results
  tc = {};
  tcmeta = struct_totex(ds.meta, 'usrmeta');
  tcdata = struct_totex(ds.data, 'usrdata');
  tcameta = struct_totex(ads.ameta, 'usrameta');
  tcadata = struct_totex(ads.adata, 'usradata');
  tc = [tcmeta; tcdata; tcameta; tcadata];
  
  ## open TeX file for writing
  fid = fopen('./latex/dsads.tex', 'w');
  
  ## print copyright information to TeX file
  fprintf(fid, '%% %s\n', ds.meta.copyright.v);
  fprintf(fid, '%% License: %s\n', ds.meta.license.v);
  fprintf(fid, '%%\n');
  
  ## write content to TeX file
  for i = 1 : size(tc, 1)
    fprintf(fid, '%s\n', tc{i});
  endfor
  fprintf(fid, '\n');
  
  ## close TeX file
  fclose(fid);

endfunction
