## Copyright 2023 Jakob Harden, Graz University of Technology (Graz, Austria)
## This script is a part of and was written in the course of the PhD study of the author.
## License: MIT, see also section "License" in README.md
##
## Plot analysis data structure
##
function plotads()
  
  ## load data set from structure directory
  ds = load('./structure/ads.oct').ads;
  
  ## plot labels
  tit1 = ds.meta.title.v;
  xlbl1 = sprintf('%s [%s]', ds.meta.xlbl.v, ds.meta.xunit.v);
  ylbl1 = sprintf('%s [%s]', ds.meta.ylbl.v, ds.meta.yunit.v);
  tit2 = ds.ameta.title.v;
  xlbl2 = sprintf('%s [%s]', ds.ameta.xlbl.v, ds.ameta.xunit.v);
  ylbl2 = sprintf('%s [%s]', ds.ameta.ylbl.v, ds.ameta.yunit.v);
  
  ## prepare analysis results for plotting
  arr = ds.adata.ymean.v;
  idx = linspace(1, max(size(arr)), max(size(arr)));
  err1 = arr - ds.adata.ymin.v;
  err2 = ds.adata.ymax.v - arr;
  
  ## plot analysis results
  figure();
  ## 1st plot: signals
  subplot(1, 2, 1);
  ## plot transformed signals, left of error bar plot
  hold on;
  plot(ds.adata.xdata.v, ds.adata.ydata.v(:, 1), sprintf(';%s;', ds.meta.fnaname.v));
  plot(ds.adata.xdata.v, ds.adata.ydata.v(:, 2), sprintf(';%s;', ds.meta.fnbname.v));
  hold off;
  title(tit1);
  xlabel(xlbl1);
  ylabel(ylbl1);
  grid on;
  ## 2nd plot: error bars, right of signal plot
  subplot(1, 2, 2);
  ## plot error bars with min/max of signals
  errorbar(idx, arr, err1, err2, '~.');
  title(tit2);
  xlabel(xlbl2);
  ylabel(ylbl2);
  xticks('manual');
  xticks(idx);
  xticklabels(ds.ameta.xticklbls.v);
  grid on;

endfunction
